Module auth_handler

Module auth_handler 

Authentication handler for different ACP auth methods.

This module provides a unified interface for handling authentication across different auth methods specified in the ACP protocol.

Structs

AuthHandler
Handles authentication based on the auth method type

Enums

AuthMethod
ACP authentication methods mirrored locally so vtcode-core does not depend on the ACP client crate.