pub fn is_safe_command(
registry: &SafeCommandRegistry,
command: &[String],
) -> boolExpand description
Evaluates if a command is safe to execute. Returns true if the command passes all safety checks.
pub fn is_safe_command(
registry: &SafeCommandRegistry,
command: &[String],
) -> boolEvaluates if a command is safe to execute. Returns true if the command passes all safety checks.