Module api

Module api 

Structs

ConfigLayerView
View of a single configuration layer for API responses.
ConfigReadRequest
Request to read the effective configuration for a workspace.
ConfigReadResponse
Response containing the merged effective configuration and layer details.
ConfigResetRequest
Request to clear one configuration layer.
ConfigResetResponse
Result of clearing one configuration layer.
ConfigService
ConfigWriteRequest
Request to write a value to a specific configuration layer.
ConfigWriteResponse
OverrideMetadata

Enums

ConfigWriteStrategy
Strategy for applying a value to the configuration.
ConfigWriteTarget
The configuration layer target for a write operation.