pub struct CustomProviderProfileConfig {Show 18 fields
pub api_format: CustomProviderApiFormat,
pub context_window: Option<usize>,
pub temperature: Option<f32>,
pub top_p: Option<f32>,
pub top_k: Option<i32>,
pub presence_penalty: Option<f32>,
pub frequency_penalty: Option<f32>,
pub max_tokens: Option<u32>,
pub reasoning_effort: Option<ReasoningEffortLevel>,
pub supports_tools: Option<bool>,
pub supports_reasoning: Option<bool>,
pub supports_reasoning_effort: Option<bool>,
pub supports_vision: Option<bool>,
pub supports_structured_output: Option<bool>,
pub supports_parallel_tool_calls: Option<bool>,
pub supports_context_caching: Option<bool>,
pub supports_responses_compaction: Option<bool>,
pub supports_context_edits: Option<bool>,
}Expand description
Sparse per-provider or per-model capability/profile settings.
Fields
api_format: CustomProviderApiFormatTyped API format for this provider/profile.
context_window: Option<usize>Optional context window size in tokens.
temperature: Option<f32>Optional sampling temperature override (0.0-2.0) sent with requests.
top_p: Option<f32>Optional nucleus-sampling override (0.0-1.0).
top_k: Option<i32>Optional top-k override (>= 0).
presence_penalty: Option<f32>Optional presence penalty override (-2.0-2.0).
frequency_penalty: Option<f32>Optional frequency penalty override (-2.0-2.0).
max_tokens: Option<u32>Optional max output tokens override (> 0).
reasoning_effort: Option<ReasoningEffortLevel>Optional reasoning effort override sent with requests for this model.
supports_tools: Option<bool>supports_reasoning: Option<bool>supports_reasoning_effort: Option<bool>supports_vision: Option<bool>supports_structured_output: Option<bool>supports_parallel_tool_calls: Option<bool>supports_context_caching: Option<bool>supports_responses_compaction: Option<bool>supports_context_edits: Option<bool>Trait Implementations
Sourceimpl Clone for CustomProviderProfileConfig
impl Clone for CustomProviderProfileConfig
Sourcefn clone(&self) -> CustomProviderProfileConfig
fn clone(&self) -> CustomProviderProfileConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CustomProviderProfileConfig
impl Debug for CustomProviderProfileConfig
Sourceimpl Default for CustomProviderProfileConfig
impl Default for CustomProviderProfileConfig
Sourcefn default() -> CustomProviderProfileConfig
fn default() -> CustomProviderProfileConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CustomProviderProfileConfig
impl<'de> Deserialize<'de> for CustomProviderProfileConfig
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<CustomProviderProfileConfig, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<CustomProviderProfileConfig, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CustomProviderProfileConfig
impl JsonSchema for CustomProviderProfileConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for CustomProviderProfileConfig
impl Serialize for CustomProviderProfileConfig
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for CustomProviderProfileConfig