pub struct McpHttpServerConfig {
pub endpoint: String,
pub api_key_env: Option<String>,
pub oauth: Option<McpOAuthConfig>,
pub protocol_version: String,
pub http_headers: HashMap<String, String>,
pub env_http_headers: HashMap<String, String>,
}Expand description
Configuration for HTTP-based MCP servers
Note: HTTP transport is partially implemented. Basic connectivity testing is supported, but full streamable HTTP MCP server support requires additional implementation using Server-Sent Events (SSE) or WebSocket connections.
Fields
endpoint: StringServer endpoint URL
api_key_env: Option<String>API key environment variable name
oauth: Option<McpOAuthConfig>Optional OAuth configuration for providers that issue bearer tokens dynamically.
protocol_version: StringProtocol version
http_headers: HashMap<String, String>Headers to include in requests
env_http_headers: HashMap<String, String>Headers whose values are sourced from environment variables
({ header-name = "ENV_VAR" }). Empty values are ignored.