pub fn detect_mimo_auth_method(
api_key: &str,
base_url: Option<&str>,
) -> MiMoAuthMethodExpand description
Detect auth method from API key prefix or base URL.
Returns PayAsYouGo as the default if no hint is available.
pub fn detect_mimo_auth_method(
api_key: &str,
base_url: Option<&str>,
) -> MiMoAuthMethodDetect auth method from API key prefix or base URL.
Returns PayAsYouGo as the default if no hint is available.