pub struct IdeContextProvidersConfig {
pub vscode_compatible: IdeContextProviderConfig,
pub zed: IdeContextProviderConfig,
pub generic: IdeContextProviderConfig,
}Fields
vscode_compatible: IdeContextProviderConfigzed: IdeContextProviderConfiggeneric: IdeContextProviderConfigTrait Implementations
Sourceimpl Clone for IdeContextProvidersConfig
impl Clone for IdeContextProvidersConfig
Sourcefn clone(&self) -> IdeContextProvidersConfig
fn clone(&self) -> IdeContextProvidersConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IdeContextProvidersConfig
impl Debug for IdeContextProvidersConfig
Sourceimpl Default for IdeContextProvidersConfig
impl Default for IdeContextProvidersConfig
Sourcefn default() -> IdeContextProvidersConfig
fn default() -> IdeContextProvidersConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for IdeContextProvidersConfig
impl<'de> Deserialize<'de> for IdeContextProvidersConfig
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<IdeContextProvidersConfig, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<IdeContextProvidersConfig, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for IdeContextProvidersConfig
impl JsonSchema for IdeContextProvidersConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for IdeContextProvidersConfig
impl Serialize for IdeContextProvidersConfig
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more