pub struct McpAllowListConfig {
pub enforce: bool,
pub default: McpAllowListRules,
pub providers: BTreeMap<String, McpAllowListRules>,
}Expand description
Allow list configuration for MCP providers
Fields
enforce: boolWhether to enforce allow list checks
default: McpAllowListRulesDefault rules applied when provider-specific rules are absent
providers: BTreeMap<String, McpAllowListRules>Provider-specific allow list rules
Implementations
Sourceimpl McpAllowListConfig
impl McpAllowListConfig
Sourcepub fn is_tool_allowed(&self, provider: &str, tool_name: &str) -> bool
pub fn is_tool_allowed(&self, provider: &str, tool_name: &str) -> bool
Determine whether a tool is permitted for the given provider
Sourcepub fn is_resource_allowed(&self, provider: &str, resource: &str) -> bool
pub fn is_resource_allowed(&self, provider: &str, resource: &str) -> bool
Determine whether a resource is permitted for the given provider
Sourcepub fn is_prompt_allowed(&self, provider: &str, prompt: &str) -> bool
pub fn is_prompt_allowed(&self, provider: &str, prompt: &str) -> bool
Determine whether a prompt is permitted for the given provider