pub struct TelemetryConfig {
pub trajectory_enabled: bool,
pub dashboards_enabled: bool,
pub sample_interval_ms: u64,
pub retention_days: u32,
pub atif_enabled: bool,
pub bottleneck_tracing: bool,
pub perf_events: bool,
pub trajectory_max_files: usize,
pub trajectory_max_age_days: u64,
pub trajectory_max_size_mb: u64,
}Fields
trajectory_enabled: booldashboards_enabled: boolEnable real-time dashboards
sample_interval_ms: u64KPI sampling interval in milliseconds
retention_days: u32Retention window for historical benchmarking (days)
atif_enabled: boolEnable ATIF (Agent Trajectory Interchange Format) trajectory export.
When enabled, sessions write an atif-trajectory.json alongside the
existing .jsonl trajectory log.
bottleneck_tracing: boolEmit bottleneck traces for slow paths
perf_events: boolEmit performance events for file I/O, spawns, and UI latency
trajectory_max_files: usizeMaximum number of rotated trajectory log files to keep per workspace
trajectory_max_age_days: u64Maximum age in days for rotated trajectory log files
trajectory_max_size_mb: u64Maximum total size in MB for all trajectory log files in a workspace