Structs
- Validation
Result - Result of a configuration validation check
Functions
- effective_
model_ context_ window - Resolve the effective context window size for a model.
- validate_
config - Validate full VTCodeConfig at startup
- validate_
model_ exists - Validate that the configured model exists in the generated model catalog.