pub async fn with_tool_cancellation<F, T>(token: CancellationToken, fut: F) -> Twhere
F: Future<Output = T>,Expand description
Run the provided future with the supplied cancellation token made available to tools.
pub async fn with_tool_cancellation<F, T>(token: CancellationToken, fut: F) -> Twhere
F: Future<Output = T>,Run the provided future with the supplied cancellation token made available to tools.