Module command_validation

Module command_validation 

Functions

sanitize_working_dir
Normalize a working directory relative to the workspace root.
validate_command
Validate whether a command is allowed to run under the execution policy.