Streaming processor for handling real-time responses from the Gemini API
This module provides functionality to process streaming responses from the Gemini API, parse them in real-time, and provide callbacks for handling each chunk of data.
Structs
- Streaming
Config - Configuration for the streaming processor
- Streaming
Processor - Streaming processor for handling real-time responses from the Gemini API
Type Aliases
- Progress
Callback - Callback for streaming timeout progress updates