pub fn get_cached_capabilities(
provider: &dyn LLMProvider,
model: &str,
) -> ProviderCapabilitiesExpand description
Extract and cache provider capabilities for a given provider and model
pub fn get_cached_capabilities(
provider: &dyn LLMProvider,
model: &str,
) -> ProviderCapabilitiesExtract and cache provider capabilities for a given provider and model