Module provider_builder

Module provider_builder 

Generic provider builder with builder-pattern construction.

Structs

ProviderBuilder
Generic provider builder to eliminate duplicate provider creation patterns

Traits

ProviderConfig
Trait for provider-specific configuration and creation

Functions

get_http_client
Retrieve a pooled HTTP client by key, falling back to the default client.
get_http_client_for_timeouts
Select an appropriate pooled HTTP client based on the timeout ceiling.