pub fn save_loop_state(
workspace_root: &Path,
state: &LoopRunState,
) -> Result<PathBuf>Expand description
Save loop run state to disk using atomic write (temp file + rename).
pub fn save_loop_state(
workspace_root: &Path,
state: &LoopRunState,
) -> Result<PathBuf>Save loop run state to disk using atomic write (temp file + rename).