Module config

Module config 

Marketplace configuration system for VT Code

This module handles the integration of marketplace settings with VT Code’s configuration system.

Structs

AutoUpdateSettings
Auto-update settings for marketplaces and plugins
InstalledPlugin
Information about an installed plugin
MarketplaceSettings
Configuration for marketplace settings that integrates with VT Code’s config system
SecuritySettings
Security and trust settings

Functions

get_marketplace_config_path
Helper function to get the marketplace config path based on VT Code’s config directory structure