Module traits

Module traits 

MCP trait abstractions for tool execution and elicitation handling.

Traits

McpElicitationHandler
Callback interface used to resolve elicitation requests from MCP providers.
McpToolExecutor
Trait abstraction used by the tool registry to talk to the MCP client.