pub async fn load_cache(path: &Path) -> Result<Option<ModelsCache>>Expand description
Read and deserialize the cache file if it exists.
pub async fn load_cache(path: &Path) -> Result<Option<ModelsCache>>Read and deserialize the cache file if it exists.