pub async fn save_cache(path: &Path, cache: &ModelsCache) -> Result<()>Expand description
Persist the cache contents to disk, creating parent directories as needed.
pub async fn save_cache(path: &Path, cache: &ModelsCache) -> Result<()>Persist the cache contents to disk, creating parent directories as needed.