ModelsManager

Struct ModelsManager 

pub struct ModelsManager { /* private fields */ }
Coordinates remote model discovery plus cached metadata on disk.

Implementations

Source

impl ModelsManager

pub fn new() -> Self

Construct a new ModelsManager with default settings

pub fn with_home(vtcode_home: PathBuf) -> Self

Construct with a specific home directory

pub fn with_provider(provider: Provider) -> Self

Construct with a specific provider

pub fn with_home_and_provider(vtcode_home: PathBuf, provider: Provider) -> Self

Construct with specific home directory and provider

pub fn set_remote_models_enabled(&mut self, enabled: bool)

Enable or disable remote model fetching

pub fn set_cache_ttl(&mut self, ttl: Duration)

Set the cache TTL

pub async fn refresh_available_models(&self) -> Result<()>

Refresh available models, using cache if fresh

pub async fn list_models(&self) -> Vec<ModelPreset>

List available models for the current provider

pub async fn list_models_for_provider( &self, provider: Provider, ) -> Vec<ModelPreset>

List available models for a specific provider

pub fn try_list_models(&self) -> Result<Vec<ModelPreset>, TryLockError>

Try to list models without async refresh (uses cache only)

pub async fn construct_model_family(&self, model: &str) -> ModelFamily

Get the model family for a given model slug

pub async fn get_model(&self, model: Option<&str>) -> String

Get the model to use, resolving defaults if not specified

pub fn get_default_model_for_provider(&self, provider: Provider) -> String

Get the default model for a specific provider

pub async fn set_provider(&self, provider: Provider)

Set the current provider

pub async fn get_provider(&self) -> Provider

Get the current provider

pub async fn find_model(&self, model_id: &str) -> Option<ModelPreset>

Find a model preset by ID

pub async fn model_exists(&self, model_id: &str) -> bool

Check if a model exists

pub fn model_exists_sync(&self, model_id: &str) -> bool

Check if a model exists (sync, uses local presets only)

This is a fast, non-blocking check that only looks at local presets. Use model_exists for the async version that includes remote models.

pub fn supported_providers() -> Vec<Provider>

Get all supported providers

pub fn client_version() -> String

Get version string for API requests