Module model_family

Module model_family 

Model family definitions and capability groupings.

A model family groups models that share certain characteristics like context windows, supported features, and prompting strategies.

Structs

ModelFamily
A model family groups models that share certain characteristics.

Enums

ShellToolType
Shell tool type preference for a model family
TruncationPolicy
Truncation policy for model output

Constants

DEFAULT_CONTEXT_WINDOW
Default context window for most models
LARGE_CONTEXT_WINDOW
Large context window (for models like Gemini)
MEDIUM_CONTEXT_WINDOW
Medium context window

Functions

find_family_for_model
Internal helper that returns a ModelFamily for the given model slug.