Module notifications

Module notifications 

Push notification system for VT Code terminal clients Handles important events like command failures, errors, policy approval requests, human in the loop interactions, completion and requests.

Structs

NotificationConfig
Notification configuration
NotificationManager
Notification manager that handles sending notifications

Enums

CompletionStatus
Status of a completed task
NotificationEvent
Types of important events that trigger notifications

Functions

apply_global_notification_config
Ensure the global manager is initialized, then apply updated configuration.
apply_global_notification_config_from_vtcode
Build and apply notification settings from VTCodeConfig.
get_global_notification_manager
Get a reference to the global notification manager
init_global_notification_manager
Initialize the global notification manager
init_global_notification_manager_with_config
Initialize the global notification manager with explicit configuration.
is_global_terminal_focused
Check if the terminal is focused using the global notification manager
notify_command_failure
Convenience function to send a command failure notification
notify_error
Convenience function to send an error notification
notify_human_in_the_loop
Convenience function to send a human in the loop notification
notify_tool_failure
Convenience function to send a tool failure notification
notify_tool_success
Convenience function to send a tool success notification
send_global_notification
Send a notification using the global notification manager
send_global_notification_force
Send a notification immediately, even when the terminal is currently focused.
set_global_notification_hook_engine
set_global_terminal_focused
Set the terminal focus state using the global notification manager