pub fn apply_global_notification_config(
config: NotificationConfig,
) -> Result<()>Expand description
Ensure the global manager is initialized, then apply updated configuration.
pub fn apply_global_notification_config(
config: NotificationConfig,
) -> Result<()>Ensure the global manager is initialized, then apply updated configuration.