pub async fn send_global_notification_force(
event: NotificationEvent,
) -> Result<(), Error>Expand description
Send a notification immediately, even when the terminal is currently focused.
pub async fn send_global_notification_force(
event: NotificationEvent,
) -> Result<(), Error>Send a notification immediately, even when the terminal is currently focused.