pub enum ItemStatus {
InProgress,
Incomplete,
Completed,
Failed,
}Expand description
Lifecycle status for items in the Open Responses model.
Per the Open Responses specification, all items are state machines that transition through these defined states during their lifecycle.
State Transitions
┌─────────────┐
│ in_progress │──────────────────────────────────┐
└──────┬──────┘ │
│ │
▼ ▼
┌─────────────┐ ┌─────────────┐ ┌─────────────┐
│ incomplete │ │ completed │ │ failed │
└─────────────┘ └─────────────┘ └─────────────┘
(terminal) (terminal) (terminal)Variants
InProgress
The model is currently emitting tokens belonging to this item.
Incomplete
The model has exhausted its token budget while emitting tokens for this item.
This is a terminal state. If an item ends in this state, it MUST be the last
item emitted, and the containing response MUST also be in an incomplete state.
Completed
The model has finished emitting tokens for this item, and/or a tool call has completed successfully. This is a terminal state.
Failed
The item processing has failed. This is a terminal state.
Implementations
Sourceimpl ItemStatus
impl ItemStatus
Sourcepub fn is_terminal(&self) -> bool
pub fn is_terminal(&self) -> bool
Returns true if this status is a terminal state (no further transitions allowed).
Sourcepub fn is_success(&self) -> bool
pub fn is_success(&self) -> bool
Returns true if this status indicates successful completion.
Sourcepub fn is_failure(&self) -> bool
pub fn is_failure(&self) -> bool
Returns true if this status indicates a failure.