Plugin caching system for VT Code
Implements the caching mechanism for plugins to ensure security and verification as described in the VT Code plugin reference.
Structs
- Plugin
Cache - Plugin cache manager
Plugin caching system for VT Code
Implements the caching mechanism for plugins to ensure security and verification as described in the VT Code plugin reference.