Module manager

Module manager 

Plugin manager for VT Code

Coordinates all plugin system components and provides a unified interface for plugin management.

Structs

DiscoveredPluginInfo
Information about a discovered non-curated plugin.
PluginManager
Main plugin manager that coordinates all plugin system components

Enums

RefreshResult
Result of a non-curated plugin cache refresh operation.