pub struct PluginManager { /* private fields */ }Expand description
Main plugin manager that coordinates all plugin system components
Implementations
Sourceimpl PluginManager
impl PluginManager
Sourcepub fn new(config: PluginRuntimeConfig, base_dir: PathBuf) -> Result<Self>
pub fn new(config: PluginRuntimeConfig, base_dir: PathBuf) -> Result<Self>
Create a new plugin manager
Sourcepub async fn install_plugin(
&self,
source: PluginSource,
name: Option<String>,
) -> PluginResult<()>
pub async fn install_plugin( &self, source: PluginSource, name: Option<String>, ) -> PluginResult<()>
Install a plugin from a source
Sourcepub async fn uninstall_plugin(&self, plugin_name: &str) -> PluginResult<()>
pub async fn uninstall_plugin(&self, plugin_name: &str) -> PluginResult<()>
Uninstall a plugin
Sourcepub async fn enable_plugin(&self, plugin_name: &str) -> PluginResult<()>
pub async fn enable_plugin(&self, plugin_name: &str) -> PluginResult<()>
Enable a plugin
Sourcepub async fn disable_plugin(&self, plugin_name: &str) -> PluginResult<()>
pub async fn disable_plugin(&self, plugin_name: &str) -> PluginResult<()>
Disable a plugin
Sourcepub async fn load_plugin(&self, plugin_path: &Path) -> PluginResult<()>
pub async fn load_plugin(&self, plugin_path: &Path) -> PluginResult<()>
Load a plugin
Sourcepub async fn get_plugin(&self, plugin_id: &str) -> PluginResult<PluginHandle>
pub async fn get_plugin(&self, plugin_id: &str) -> PluginResult<PluginHandle>
Get information about a plugin
Sourcepub async fn list_installed_plugins(&self) -> PluginResult<Vec<String>>
pub async fn list_installed_plugins(&self) -> PluginResult<Vec<String>>
List all installed plugins
Sourcepub async fn list_loaded_plugins(&self) -> Vec<PluginHandle>
pub async fn list_loaded_plugins(&self) -> Vec<PluginHandle>
List all loaded plugins
Sourcepub async fn process_plugin_components(
&self,
plugin_path: &Path,
manifest: &PluginManifest,
) -> Result<PluginComponents>
pub async fn process_plugin_components( &self, plugin_path: &Path, manifest: &PluginManifest, ) -> Result<PluginComponents>
Process all components for a plugin
Sourcepub async fn is_plugin_enabled(&self, plugin_id: &str) -> bool
pub async fn is_plugin_enabled(&self, plugin_id: &str) -> bool
Check if a plugin is enabled
Sourcepub async fn cache_plugin(
&self,
plugin_id: &str,
source_path: &Path,
) -> PluginResult<PathBuf>
pub async fn cache_plugin( &self, plugin_id: &str, source_path: &Path, ) -> PluginResult<PathBuf>
Cache a plugin for security
Sourcepub async fn get_cached_plugin(&self, plugin_id: &str) -> Option<PathBuf>
pub async fn get_cached_plugin(&self, plugin_id: &str) -> Option<PathBuf>
Get cached plugin path
Sourcepub async fn refresh_non_curated_plugin_cache(
&self,
roots: &[PathBuf],
) -> Result<RefreshResult>
pub async fn refresh_non_curated_plugin_cache( &self, roots: &[PathBuf], ) -> Result<RefreshResult>
Refresh the non-curated plugin cache using dynamic roots (workspace directories).
This method is triggered from plugin/list commands rather than at startup,
allowing it to access the current working directories (roots/cwds) required
to locate marketplace.json files that are not persisted in the config.
Uses version information from plugin.json to determine if a refresh is needed.
The refresh worker state prevents race conditions during concurrent refreshes.
Errors
Returns an error if the refresh worker lock is poisoned or if root scanning fails.