pub fn generate_tool_guidelines(
available_tools: &[String],
capability_level: Option<CapabilityLevel>,
) -> StringExpand description
Generate compact cross-tool guidance based on the tools available in the session.
pub fn generate_tool_guidelines(
available_tools: &[String],
capability_level: Option<CapabilityLevel>,
) -> StringGenerate compact cross-tool guidance based on the tools available in the session.