pub fn render_environment_addenda(
vtcode_config: Option<&VTCodeConfig>,
prompt_context: Option<&PromptContext>,
) -> Option<String>Expand description
Assemble the environment addenda section for the system prompt.
pub fn render_environment_addenda(
vtcode_config: Option<&VTCodeConfig>,
prompt_context: Option<&PromptContext>,
) -> Option<String>Assemble the environment addenda section for the system prompt.