Module file_references

Module file_references 

File reference validation for Agent Skills

Validates file references in SKILL.md bodies to ensure they meet the Agent Skills specification requirements.

Structs

FileReferenceValidator
Validates that file references in skill instructions follow the Agent Skills spec