pub struct PluginLoader { /* private fields */ }Expand description
Plugin loader responsible for discovering and loading native plugins
Implementations
Sourceimpl PluginLoader
impl PluginLoader
Sourcepub fn add_trusted_dir(&mut self, path: PathBuf) -> &mut Self
pub fn add_trusted_dir(&mut self, path: PathBuf) -> &mut Self
Add a trusted plugin directory
Sourcepub fn trusted_dirs(&self) -> &[PathBuf]
pub fn trusted_dirs(&self) -> &[PathBuf]
Get trusted plugin directories
Sourcepub fn load_plugin(
&self,
plugin_path: &Path,
) -> Result<Box<dyn NativePluginTrait>>
pub fn load_plugin( &self, plugin_path: &Path, ) -> Result<Box<dyn NativePluginTrait>>
Load a plugin from a specific path
Sourcepub fn discover_plugins(&self) -> Result<Vec<Box<dyn NativePluginTrait>>>
pub fn discover_plugins(&self) -> Result<Vec<Box<dyn NativePluginTrait>>>
Discover all plugins in trusted directories
Sourcepub fn library_filename(&self, name: &str) -> String
pub fn library_filename(&self, name: &str) -> String
Convert a plugin name to a library filename for the current platform