pub fn load_primary_memory_appendix(
workspace_root: &Path,
agent_name: &str,
scope: Option<SubagentMemoryScope>,
) -> Result<Option<String>>Expand description
Loads a read-only memory appendix for the primary agent from a subagent’s memory scope.
Unlike load_memory_appendix, this does not create directories or prompt for writes.