Module exec_session

Module exec_session 

Structs

ExecSessionCompletionEvent
Notification emitted after a background process has been confirmed exited.
ExecSessionManager
ExecSessionUiSnapshot
Bounded data used by the Local Agents drawer for one raw command session.

Enums

BackgroundShortcutResult
Result of the Ctrl+B foreground-session handoff request.
ExecSessionBackend

Constants

MAX_BACKGROUND_PROCESSES
Maximum number of live background command sessions owned by one runtime.