normalised_code_search_identity

Function normalised_code_search_identity 

pub fn normalised_code_search_identity(args: &Value) -> Option<String>
Normalised identity for result caching and replay.

The effective result limit affects both the returned results and echoed filters, so it is part of this identity.