Module intercept_apply_patch

Module intercept_apply_patch 

Apply Patch Interception (from Codex)

This module provides the ability to intercept shell commands that contain apply_patch invocations, redirecting them to the proper patch application flow with approval and sandbox handling.

Structs

ApplyPatchRequest
Apply patch request (from Codex)

Enums

ApplyPatchError
Errors from apply_patch interception

Constants

CODEX_APPLY_PATCH_ARG
The argument used to indicate apply_patch mode (from Codex)

Functions

intercept_apply_patch
Intercept apply_patch from shell command (from Codex)
maybe_parse_apply_patch_from_command
Check if a command contains an apply_patch invocation (from Codex)