Module orchestrator

Module orchestrator 

Legacy orchestrator compatibility shim.

Keep this module importable for older handler code, but delegate all behavior to the active sandboxing and tool orchestrator modules.

Re-exports

pub use super::sandboxing::Approvable;
pub use super::sandboxing::ApprovalCtx;
pub use super::sandboxing::ApprovalStore;
pub use super::sandboxing::BoxFuture;
pub use super::sandboxing::CommandSpec;
pub use super::sandboxing::ExecEnv;
pub use super::sandboxing::ExecToolCallOutput;
pub use super::sandboxing::NetworkAccess;
pub use super::sandboxing::ReviewDecision;
pub use super::sandboxing::SandboxAttempt;
pub use super::sandboxing::SandboxConfig;
pub use super::sandboxing::SandboxManager;
pub use super::sandboxing::SandboxOverride;
pub use super::sandboxing::SandboxPolicy;
pub use super::sandboxing::SandboxTransformError;
pub use super::sandboxing::SandboxType;
pub use super::sandboxing::Sandboxable;
pub use super::sandboxing::SandboxablePreference;
pub use super::sandboxing::ToolCtx;
pub use super::sandboxing::ToolError;
pub use super::sandboxing::ToolRuntime;
pub use super::sandboxing::canonical_sandbox_policy;
pub use super::sandboxing::default_exec_approval_requirement;
pub use super::sandboxing::execute_env;
pub use super::sandboxing::with_cached_approval;
pub use super::tool_orchestrator::ToolOrchestrator;

Structs

ExecPolicyAmendment
A proposed amendment to the execution policy.
RejectConfig
Fine-grained rejection controls for approval prompts.

Enums

AskForApproval
Policy for when to ask for approval before executing commands.
ExecApprovalRequirement
Requirement for approval before executing a command.