Module plan_task_tracker

Module plan_task_tracker 

Plan-mode scoped task tracker persisted next to the active plan file.

This tracker is intended for Plan Mode only and writes a sidecar markdown file next to the active plan file (<plan>.tasks.md).

Structs

PlanTaskTrackerArgs
PlanTaskTrackerTool