Module planning_task_tracker

Module planning_task_tracker 

Planning workflow scoped task tracker persisted next to the active plan file.

This tracker is intended for Planning workflow only and writes a sidecar markdown file next to the active plan file (<plan>.tasks.md).

Structs

PlanningTaskTrackerArgs
PlanningTaskTrackerTool