Module names

Module names 

Re-exports

pub use crate::utils::tool_name_parsing::canonical_tool_name;

Functions

is_apply_patch_shell_collision_command
Returns true when a full shell command line tries to run the apply_patch tool as a shell binary (e.g. apply_patch, or /usr/bin/applypatch --help). Only the first token is considered, so sudo apply_patch is not a collision.