pub struct SessionToolCatalogState { /* private fields */ }Implementations
Sourceimpl SessionToolCatalogState
impl SessionToolCatalogState
pub fn new() -> Self
pub fn current_version(&self) -> u64
pub fn current_epoch(&self) -> u64
pub fn mark_pending_refresh(&self, reason: &str)
pub fn note_explicit_refresh(&self, reason: &str) -> u64
pub fn change_notifier( self: &Arc<Self>, ) -> Arc<dyn Fn(&'static str) + Send + Sync> ⓘ
pub async fn note_tool_references( &self, tools: &Arc<RwLock<Vec<ToolDefinition>>>, tool_references: &[String], ) -> Option<u64>
Sourcepub async fn embedding_index(
&self,
tools: &Arc<RwLock<Vec<ToolDefinition>>>,
) -> Arc<ToolEmbeddingIndex> ⓘ
pub async fn embedding_index( &self, tools: &Arc<RwLock<Vec<ToolDefinition>>>, ) -> Arc<ToolEmbeddingIndex> ⓘ
Get or build the client-side tool embedding index.
The index is rebuilt when the catalog epoch changes (tools added/removed, deferred tools expanded). This is the infrastructure for client-side embedding-guided tool search described in the Microsoft article.
Sourcepub async fn search_tools(
&self,
tools: &Arc<RwLock<Vec<ToolDefinition>>>,
query: &str,
max_results: usize,
) -> Vec<ToolSearchResult>
pub async fn search_tools( &self, tools: &Arc<RwLock<Vec<ToolDefinition>>>, query: &str, max_results: usize, ) -> Vec<ToolSearchResult>
Search tools by query using the client-side embedding index.
Returns tools ranked by BM25-inspired relevance scoring. This is the client-side alternative to provider-side tool search, matching the article’s description: “Rather than lexical matching over tool names and descriptions, we use our embedding model to compare the query against vector representations of every available tool.”
pub async fn filtered_snapshot_with_stats( &self, tools: &Arc<RwLock<Vec<ToolDefinition>>>, planning_active: bool, request_user_input_enabled: bool, ) -> SessionToolCatalogSnapshot
Sourcepub async fn filtered_snapshot_with_stats_ex(
&self,
tools: &Arc<RwLock<Vec<ToolDefinition>>>,
planning_active: bool,
request_user_input_enabled: bool,
stable_catalog: bool,
) -> SessionToolCatalogSnapshot
pub async fn filtered_snapshot_with_stats_ex( &self, tools: &Arc<RwLock<Vec<ToolDefinition>>>, planning_active: bool, request_user_input_enabled: bool, stable_catalog: bool, ) -> SessionToolCatalogSnapshot
Same as Self::filtered_snapshot_with_stats but can keep a
cache-stable tool catalog across planning/execution toggles.
pub fn snapshot_for_defs( &self, defs: Vec<ToolDefinition>, planning_active: bool, request_user_input_enabled: bool, ) -> SessionToolCatalogSnapshot
pub fn snapshot_for_stable_defs_with_active_names( &self, defs: Vec<ToolDefinition>, active_tool_names: Vec<String>, planning_active: bool, request_user_input_enabled: bool, ) -> SessionToolCatalogSnapshot