pub struct ToolRegistration { /* private fields */ }Implementations
Sourceimpl ToolRegistration
impl ToolRegistration
pub fn with_network_access(self, access: ToolNetworkAccess) -> Self
pub fn new( name: impl Into<Arc<str>>, capability: CapabilityLevel, uses_pty: bool, executor: ToolExecutorFn, ) -> Self
pub fn from_tool( name: impl Into<Arc<str>>, capability: CapabilityLevel, tool: Arc<dyn Tool>, ) -> Self
pub fn from_tool_with_metadata( name: impl Into<Arc<str>>, capability: CapabilityLevel, tool: Arc<dyn Tool>, metadata: ToolRegistrationSpec, ) -> Self
pub fn from_tool_instance<T>(
name: impl Into<Arc<str>>,
capability: CapabilityLevel,
tool: T,
) -> Selfwhere
T: Tool + 'static,
Sourcepub fn from_cgp_tool<Ctx>(
name: impl Into<Arc<str>>,
capability: CapabilityLevel,
facade: ToolFacade<Ctx>,
) -> Selfwhere
ToolFacade<Ctx>: Tool + 'static,
pub fn from_cgp_tool<Ctx>(
name: impl Into<Arc<str>>,
capability: CapabilityLevel,
facade: ToolFacade<Ctx>,
) -> Selfwhere
ToolFacade<Ctx>: Tool + 'static,
Register a tool wrapped with a CGP runtime context.
Wraps an existing Arc<dyn Tool> in a CGP ToolFacade with the
specified runtime context’s approval, metadata, sandbox, logging,
cache, and retry providers.
Prefer wrap_native_tool_interactive() or wrap_native_tool_ci() when
the caller still owns the concrete tool instance. Use this bridge when the
tool already has genuine shared ownership.
Example
use vtcode_core::components::{InteractiveCtx, ToolBridgeCtx, wrap_tool_interactive};
let tool: Arc<dyn Tool> = Arc::new(MyTool);
let reg = ToolRegistration::from_cgp_tool(
"my_tool",
CapabilityLevel::Basic,
wrap_tool_interactive(tool, workspace_root),
);pub fn with_llm_visibility(self, expose: bool) -> Self
pub fn with_catalog_source(self, catalog_source: ToolCatalogSource) -> Self
pub fn with_pty(self, uses_pty: bool) -> Self
pub fn with_deprecated(self, deprecated: bool) -> Self
pub fn with_deprecation_message(self, message: impl Into<String>) -> Self
pub fn with_cgp_wrapped(self, wrapped: bool) -> Self
pub fn with_handler(self, handler: ToolHandler) -> Self
pub fn with_native_cgp_factory(self, factory: NativeCgpToolFactory) -> Self
pub fn name(&self) -> &str
Sourcepub fn capability(&self) -> CapabilityLevel
pub fn capability(&self) -> CapabilityLevel
Returns the capability level of this tool.
Sourcepub fn catalog_source(&self) -> ToolCatalogSource
pub fn catalog_source(&self) -> ToolCatalogSource
Returns the catalog source of this tool.
Sourcepub fn expose_in_llm(&self) -> bool
pub fn expose_in_llm(&self) -> bool
Returns whether this tool is visible to the LLM.
Sourcepub fn is_deprecated(&self) -> bool
pub fn is_deprecated(&self) -> bool
Returns whether this tool is deprecated.
Sourcepub fn deprecation_message(&self) -> Option<&str>
pub fn deprecation_message(&self) -> Option<&str>
Returns the deprecation message if this tool is deprecated.
Sourcepub fn is_cgp_wrapped(&self) -> bool
pub fn is_cgp_wrapped(&self) -> bool
Returns whether this tool is CGP-wrapped.
Sourcepub fn handler(&self) -> ToolHandler
pub fn handler(&self) -> ToolHandler
Returns the tool handler implementation.
Sourcepub fn native_cgp_factory(&self) -> Option<NativeCgpToolFactory>
pub fn native_cgp_factory(&self) -> Option<NativeCgpToolFactory>
Returns the native CGP factory if set.
Sourcepub fn metadata(&self) -> &ToolRegistrationSpec
pub fn metadata(&self) -> &ToolRegistrationSpec
Returns a reference to the tool registration metadata.
Sourcepub fn parameter_schema(&self) -> Option<&Value>
pub fn parameter_schema(&self) -> Option<&Value>
Returns the parameter JSON schema (delegates to metadata).
Sourcepub fn config_schema(&self) -> Option<&Value>
pub fn config_schema(&self) -> Option<&Value>
Returns the configuration JSON schema (delegates to metadata).
Sourcepub fn state_schema(&self) -> Option<&Value>
pub fn state_schema(&self) -> Option<&Value>
Returns the state JSON schema (delegates to metadata).
Sourcepub fn prompt_path(&self) -> Option<&str>
pub fn prompt_path(&self) -> Option<&str>
Returns the prompt file path (delegates to metadata).
Sourcepub fn default_permission(&self) -> Option<ToolPolicy>
pub fn default_permission(&self) -> Option<ToolPolicy>
Returns the default permission policy (delegates to metadata).
Sourcepub fn with_metadata(self, metadata: ToolRegistrationSpec) -> Self
pub fn with_metadata(self, metadata: ToolRegistrationSpec) -> Self
Replaces the tool registration metadata.
Sourcepub fn with_description(self, description: impl Into<String>) -> Self
pub fn with_description(self, description: impl Into<String>) -> Self
Sets the tool description (delegates to metadata).
Sourcepub fn with_prompt_path(self, path: impl Into<String>) -> Self
pub fn with_prompt_path(self, path: impl Into<String>) -> Self
Sets the prompt file path (delegates to metadata).
Sourcepub fn with_parameter_schema(self, schema: Value) -> Self
pub fn with_parameter_schema(self, schema: Value) -> Self
Sets the parameter JSON schema (delegates to metadata).
Sourcepub fn with_config_schema(self, schema: Value) -> Self
pub fn with_config_schema(self, schema: Value) -> Self
Sets the configuration JSON schema (delegates to metadata).
Sourcepub fn with_state_schema(self, schema: Value) -> Self
pub fn with_state_schema(self, schema: Value) -> Self
Sets the state JSON schema (delegates to metadata).
Sourcepub fn with_permission(self, permission: ToolPolicy) -> Self
pub fn with_permission(self, permission: ToolPolicy) -> Self
Sets the default permission policy (delegates to metadata).
Sourcepub fn with_allowlist(
self,
patterns: impl IntoIterator<Item = impl Into<String>>,
) -> Self
pub fn with_allowlist( self, patterns: impl IntoIterator<Item = impl Into<String>>, ) -> Self
Adds glob patterns to the allowlist (delegates to metadata).
Sourcepub fn with_denylist(
self,
patterns: impl IntoIterator<Item = impl Into<String>>,
) -> Self
pub fn with_denylist( self, patterns: impl IntoIterator<Item = impl Into<String>>, ) -> Self
Adds glob patterns to the denylist (delegates to metadata).
Sourcepub fn with_aliases(
self,
aliases: impl IntoIterator<Item = impl Into<String>>,
) -> Self
pub fn with_aliases( self, aliases: impl IntoIterator<Item = impl Into<String>>, ) -> Self
Adds alternative names for the tool (delegates to metadata).
Sourcepub fn with_server_hint(self, hint: impl Into<String>) -> Self
pub fn with_server_hint(self, hint: impl Into<String>) -> Self
Sets the MCP server hint (delegates to metadata).
Sourcepub fn with_behavior(self, behavior: ToolBehavior) -> Self
pub fn with_behavior(self, behavior: ToolBehavior) -> Self
Sets the tool behavior classification (delegates to metadata).