Module request_response

Module request_response 

Structs

ToolCallRequest
Canonical tool call request used across tool execution layers.
ToolCallResponse
Canonical tool call response used across tool execution layers.