pub struct TerminalAppLauncher { /* private fields */ }Expand description
Manages launching terminal applications
Implementations
Sourceimpl TerminalAppLauncher
impl TerminalAppLauncher
Sourcepub fn launch_editor(&self, file: Option<PathBuf>) -> Result<Option<String>>
pub fn launch_editor(&self, file: Option<PathBuf>) -> Result<Option<String>>
Launch user’s preferred editor with optional file
If a file is provided, it will be opened in the editor. If no file is provided, a temporary file will be created and its contents returned after editing.
Uses the configured editor command, then VISUAL/EDITOR, then common editor defaults.
Errors
Returns an error if the editor fails to launch or if file operations fail.
Sourcepub fn launch_editor_with_config(
&self,
file: Option<PathBuf>,
config: EditorLaunchConfig,
) -> Result<Option<String>>
pub fn launch_editor_with_config( &self, file: Option<PathBuf>, config: EditorLaunchConfig, ) -> Result<Option<String>>
Launch user’s preferred editor with explicit launch configuration.
preferred_editor, when set, takes precedence over VISUAL/EDITOR env vars.
Sourcepub fn launch_editor_target_with_config(
&self,
target: Option<EditorTarget>,
config: EditorLaunchConfig,
) -> Result<Option<String>>
pub fn launch_editor_target_with_config( &self, target: Option<EditorTarget>, config: EditorLaunchConfig, ) -> Result<Option<String>>
Launch user’s preferred editor with an optional file target and location.
preferred_editor, when set, takes precedence over VISUAL/EDITOR env vars.
pub fn run_command_with_strategy( &self, command: &str, strategy: TerminalCommandStrategy, ) -> Result<TerminalAppResult>
Sourcepub fn launch_git_interface(&self) -> Result<()>
pub fn launch_git_interface(&self) -> Result<()>
Launch git interface (Lazygit or interactive git)
This will attempt to launch Lazygit if available, otherwise falls back to an interactive git command.
Errors
Returns an error if the git interface fails to launch.