Structs
Enums
Functions
- builtin_
tool_ behavior - canonical_
unified_ exec_ tool_ name - classify_
tool_ intent - is_
command_ run_ tool_ call - is_
edited_ file_ conflict_ guarded_ call - is_
parallel_ safe_ call - normalize_
unified_ search_ args - Normalize unified_search args so case/shape variants still pass schema checks.
- remap_
unified_ file_ command_ args_ to_ unified_ exec - should_
use_ spool_ reference_ only - unified_
exec_ action - Determine the action for unified_exec tool based on args. Returns the action string or None if no inference is possible.
- unified_
exec_ action_ in - unified_
exec_ action_ is - unified_
file_ action - Determine the action for unified_file tool based on args. Returns the action string or a default if inference is possible.
- unified_
file_ action_ in - unified_
file_ action_ is - unified_
search_ action - Determine the action for unified_search tool based on args. Returns the action string or None if no inference is possible.
- unified_
search_ action_ in - unified_
search_ action_ is