build_turn_metadata_value

Function build_turn_metadata_value 

pub fn build_turn_metadata_value(cwd: &Path) -> Result<Value>
Build turn metadata as a serde_json::Value for direct use in LLM requests.

Arguments

  • cwd - The working directory to collect metadata from

Returns

A serde_json::Value containing the turn metadata, or Null if metadata collection fails or the directory is not in a git repository.