Structs
- Slash
Command Info - Metadata describing a slash command supported by the chat interface.
Statics
- SLASH_
COMMANDS - Collection of slash command definitions in the order they should be displayed.
Functions
- find_
command - find_
visible_ command - suggestions_
for - Returns slash command metadata that match the provided prefix (case insensitive).
- suggestions_
for_ terminal - visible_
commands - visible_
commands_ for_ terminal