pub fn suggestions_for(prefix: &str) -> Vec<&'static SlashCommandInfo>Expand description
Returns slash command metadata that match the provided prefix (case insensitive).
pub fn suggestions_for(prefix: &str) -> Vec<&'static SlashCommandInfo>Returns slash command metadata that match the provided prefix (case insensitive).