Module theme_config

Module theme_config 

Theme Configuration File Support

Parses custom .vtcode/theme.toml files with Git/LS-style syntax for colors. This allows users to customize colors beyond system defaults.

Structs

CliColors
Colors for CLI elements like prompts, messages, etc.
DiffColors
Colors for diff rendering
FileColors
File type colors using LS_COLORS-style patterns
ParsedCliColors
Parsed CLI colors with anstyle::Style values
ParsedDiffColors
Parsed diff colors with anstyle::Style values
ParsedFileColors
Parsed file colors with anstyle::Style values
ParsedStatusColors
Parsed status colors with anstyle::Style values
StatusColors
Colors for status output
ThemeConfig
Theme configuration that can be loaded from a .vtcode/theme.toml file