Module theme_manager

Module theme_manager 

Theme manager for loading and applying custom themes. Theme Manager for loading and applying custom theme configurations

This module provides functionality to load custom theme configurations from .vtcode/theme.toml files and apply them to the application.

Structs

ThemeManager
Loads and manages theme configuration from .vtcode/theme.toml and Git config.