Module path

Module path 

Path utility functions

Re-exports from vtcode-commons for backward compatibility.

Functions

canonicalize_allow_missing
Canonicalize a path, walking up to find the nearest existing ancestor for new files.
canonicalize_workspace
Canonicalize a path with fallback to the original path if canonicalization fails.
ensure_path_within_workspace
Ensure a candidate path is inside the workspace root after lexical normalization.
normalize_ascii_identifier
Normalize identifiers to ASCII alphanumerics with lowercase output.
normalize_path
Normalize a path by resolving . and .. components lexically.
resolve_workspace_path
Resolve a path relative to a workspace root and ensure it stays within it.