Module session_archive

Module session_archive 

Structs

SearchResult
SessionArchive
SessionArchiveMetadata
SessionContinuationMetadata
SessionListing
SessionMessage
SessionProgress
SessionProgressArgs
SessionSnapshot
VerifiedSessionArchiveIdentifier
An archive identifier derived from a loaded session listing.

Enums

SessionContinuationExhaustionReason
SessionContinuationRecommendedAction
SessionForkMode
SessionProgressPersistenceStatus
Outcome of an asynchronous session-progress checkpoint.

Constants

SESSION_DIR_ENV
SESSION_MAX_AGE_DAYS_ENV
SESSION_MAX_FILES_ENV
SESSION_MAX_SIZE_MB_ENV

Functions

apply_session_history_config_from_vtcode
find_session_by_id_or_name
Find a saved session by ID or name for TUI /resume command.
find_session_by_identifier
Find a session archive by its identifier (file stem) without needing to list all sessions.
generate_session_archive_identifier
history_persistence_enabled
list_recent_sessions
reserve_session_archive_identifier
Reserve a unique session archive identifier for the current process.
search_sessions
Search for a query string across recent sessions. Returns a list of SearchResult sorted by relevance (or recency).
session_listing_matches_workspace
session_workspace_path