Agent2Agent (A2A) Protocol support for VT Code.
Re-exported from vtcode-a2a for backward compatibility.
Modules
- agent_
card - Agent Card for A2A Protocol
- cli
- A2A Protocol CLI commands
- client
- A2A client for interacting with remote A2A agents. Provides helper methods for discovery, task operations, and streaming.
- errors
- A2A Protocol error types and error codes
- rpc
- JSON-RPC 2.0 structures for A2A Protocol
- server
- A2A HTTP Server using axum
- task_
manager - A2A Task Manager
- types
- A2A Protocol core data types
- webhook
- Webhook delivery for A2A push notifications
Structs
- A2aClient
- HTTP client for interacting with A2A agents
- Agent
Capabilities - Agent capabilities declaration
- Agent
Card - Agent Card - metadata describing an A2A agent
- Agent
Provider - Agent provider/organization details
- Agent
Skill - A specific capability/skill of an agent
- Artifact
- A tangible output generated by a task
- Json
RpcError - JSON-RPC 2.0 Error
- Json
RpcRequest - JSON-RPC 2.0 Request
- Json
RpcResponse - JSON-RPC 2.0 Response
- Message
- A single unit of communication
- Send
Streaming Message Response - Base wrapper for streaming message response
- Task
- Represents a stateful unit of work
- Task
Manager - A2A Task Manager - handles task creation, updates, and queries
- Task
Push Notification Config - Configuration for push notification delivery
- Task
Status - Task status with state, optional message, and timestamp
- Webhook
Notifier - Webhook notifier for delivering A2A events
Enums
- A2aError
- A2A protocol error
- A2aError
Code - A2A error code enum for type-safe error handling
- File
Content - File content representation
- Message
Role - Role of the message sender
- Part
- Content part types: text, file, or structured data
- Streaming
Event - Streaming event types (discriminated by ‘type’ field)
- Task
State - Task lifecycle states as defined in the A2A specification
- Webhook
Error - Webhook delivery errors
Functions
- shutdown_
signal_ logged - Wait for a process shutdown signal and log listener errors.
Type Aliases
- A2aResult
- A2A Result type alias