Authentication handler for different ACP auth methods.
This module provides a unified interface for handling authentication across different auth methods specified in the ACP protocol.
Structs
- Auth
Handler - Handles authentication based on the auth method type
Enums
- Auth
Method - ACP authentication methods mirrored locally so
vtcode-coredoes not depend on the ACP client crate.