Structs
- Config
Layer View - View of a single configuration layer for API responses.
- Config
Read Request - Request to read the effective configuration for a workspace.
- Config
Read Response - Response containing the merged effective configuration and layer details.
- Config
Reset Request - Request to clear one configuration layer.
- Config
Reset Response - Result of clearing one configuration layer.
- Config
Service - Config
Write Request - Request to write a value to a specific configuration layer.
- Config
Write Response - Override
Metadata
Enums
- Config
Write Strategy - Strategy for applying a value to the configuration.
- Config
Write Target - The configuration layer target for a write operation.