pub struct OpenResponsesConfig {
pub enabled: bool,
pub emit_events: bool,
pub include_extensions: bool,
pub map_tool_calls: bool,
pub include_reasoning: bool,
}Expand description
Open Responses specification compliance configuration
Enables vendor-neutral LLM API format per the Open Responses specification (https://www.openresponses.org/). When enabled, VT Code emits semantic streaming events and uses standardized response/item structures.
Fields
enabled: boolEnable Open Responses specification compliance layer When true, VT Code emits semantic streaming events alongside internal events Default: false (opt-in feature)
emit_events: boolEmit Open Responses events to the event sink When true, streaming events follow Open Responses format (response.created, response.output_item.added, response.output_text.delta, etc.)
include_extensions: boolInclude VT Code extension items (vtcode:file_change, vtcode:web_search, etc.) When false, extension items are omitted from the Open Responses output
map_tool_calls: boolMap internal tool calls to Open Responses function_call items When true, command executions and MCP tool calls are represented as function_call items
include_reasoning: boolInclude reasoning items in Open Responses output When true, model reasoning/thinking is exposed as reasoning items