Function get_git_repo_root
Source pub fn get_git_repo_root(cwd: &Path) -> Result<Option<String>>
Get the repository root path for the given working directory.
Arguments
cwd - The working directory to run git commands in
Returns
The absolute path to the repository root, or None if not in a git repository.