Generic provider builder with builder-pattern construction.
Structs
- Provider
Builder - Generic provider builder to eliminate duplicate provider creation patterns
Traits
- Provider
Config - Trait for provider-specific configuration and creation
Functions
- get_
http_ client - Retrieve a pooled HTTP client by key, falling back to the default client.
- get_
http_ client_ for_ timeouts - Select an appropriate pooled HTTP client based on the timeout ceiling.