Marketplace configuration system for VT Code
This module handles the integration of marketplace settings with VT Code’s configuration system.
Structs
- Auto
Update Settings - Auto-update settings for marketplaces and plugins
- Installed
Plugin - Information about an installed plugin
- Marketplace
Settings - Configuration for marketplace settings that integrates with VT Code’s config system
- Security
Settings - Security and trust settings
Functions
- get_
marketplace_ config_ path - Helper function to get the marketplace config path based on VT Code’s config directory structure