Model family definitions and capability groupings.
A model family groups models that share certain characteristics like context windows, supported features, and prompting strategies.
Structs
- Model
Family - A model family groups models that share certain characteristics.
Enums
- Shell
Tool Type - Shell tool type preference for a model family
- Truncation
Policy - Truncation policy for model output
Constants
- DEFAULT_
CONTEXT_ WINDOW - Default context window for most models
- LARGE_
CONTEXT_ WINDOW - Large context window (for models like Gemini)
- MEDIUM_
CONTEXT_ WINDOW - Medium context window
Functions
- find_
family_ for_ model - Internal helper that returns a
ModelFamilyfor the given model slug.