Push notification system for VT Code terminal clients Handles important events like command failures, errors, policy approval requests, human in the loop interactions, completion and requests.
Structs
- Notification
Config - Notification configuration
- Notification
Manager - Notification manager that handles sending notifications
Enums
- Completion
Status - Status of a completed task
- Notification
Event - Types of important events that trigger notifications
Functions
- apply_
global_ notification_ config - Ensure the global manager is initialized, then apply updated configuration.
- apply_
global_ notification_ config_ from_ vtcode - Build and apply notification settings from VTCodeConfig.
- get_
global_ notification_ manager - Get a reference to the global notification manager
- init_
global_ notification_ manager - Initialize the global notification manager
- init_
global_ notification_ manager_ with_ config - Initialize the global notification manager with explicit configuration.
- is_
global_ terminal_ focused - Check if the terminal is focused using the global notification manager
- notify_
command_ failure - Convenience function to send a command failure notification
- notify_
error - Convenience function to send an error notification
- notify_
human_ in_ the_ loop - Convenience function to send a human in the loop notification
- notify_
tool_ failure - Convenience function to send a tool failure notification
- notify_
tool_ success - Convenience function to send a tool success notification
- send_
global_ notification - Send a notification using the global notification manager
- send_
global_ notification_ force - Send a notification immediately, even when the terminal is currently focused.
- set_
global_ notification_ hook_ engine - set_
global_ terminal_ focused - Set the terminal focus state using the global notification manager