pub fn export_skill_bundle(skill_root: &Path) -> Result<Vec<u8>>Expand description
Export a skill directory to a zip bundle (bytes)
Walks the skill directory and creates a zip archive. The archive preserves the directory structure with the skill name as root.