pub struct SimpleIndexer { /* private fields */ }Expand description
Simple file indexer.
Implementations
Sourceimpl SimpleIndexer
impl SimpleIndexer
Sourcepub fn new(workspace_root: PathBuf) -> SimpleIndexer
pub fn new(workspace_root: PathBuf) -> SimpleIndexer
Create a new simple indexer with default VT Code paths.
Sourcepub fn with_config(config: SimpleIndexerConfig) -> SimpleIndexer
pub fn with_config(config: SimpleIndexerConfig) -> SimpleIndexer
Create a simple indexer with the provided configuration.
Sourcepub fn with_index_dir(
workspace_root: PathBuf,
index_dir: PathBuf,
) -> SimpleIndexer
pub fn with_index_dir( workspace_root: PathBuf, index_dir: PathBuf, ) -> SimpleIndexer
Create a new simple indexer using a custom index directory.
Sourcepub fn with_components(
config: SimpleIndexerConfig,
storage: Arc<dyn IndexStorage>,
filter: Arc<dyn TraversalFilter>,
) -> SimpleIndexer
pub fn with_components( config: SimpleIndexerConfig, storage: Arc<dyn IndexStorage>, filter: Arc<dyn TraversalFilter>, ) -> SimpleIndexer
Create an indexer with explicit storage and traversal filter implementations.
Sourcepub fn with_storage(self, storage: Arc<dyn IndexStorage>) -> SimpleIndexer
pub fn with_storage(self, storage: Arc<dyn IndexStorage>) -> SimpleIndexer
Replace the storage backend used to persist index entries.
Sourcepub fn with_filter(self, filter: Arc<dyn TraversalFilter>) -> SimpleIndexer
pub fn with_filter(self, filter: Arc<dyn TraversalFilter>) -> SimpleIndexer
Replace the traversal filter used to decide which files and directories are indexed.
Sourcepub fn workspace_root(&self) -> &Path
pub fn workspace_root(&self) -> &Path
Get the workspace root path.
Sourcepub fn index_directory(&mut self, dir_path: &Path) -> Result<(), Error>
pub fn index_directory(&mut self, dir_path: &Path) -> Result<(), Error>
Index all files in directory recursively. Respects .gitignore, .ignore, and other ignore files. SECURITY: Always skips hidden files and sensitive data (.env, .git, etc.)
Sourcepub fn discover_files(&self, dir_path: &Path) -> Vec<String>
pub fn discover_files(&self, dir_path: &Path) -> Vec<String>
Discover all files in directory recursively without indexing them.
This is much faster than index_directory as it avoids hashing and persistence.
Sourcepub fn search(
&self,
pattern: &str,
path_filter: Option<&str>,
) -> Result<Vec<SearchResult>, Error>
pub fn search( &self, pattern: &str, path_filter: Option<&str>, ) -> Result<Vec<SearchResult>, Error>
Search files using regex pattern.
Sourcepub fn find_files(&self, pattern: &str) -> Result<Vec<String>, Error>
pub fn find_files(&self, pattern: &str) -> Result<Vec<String>, Error>
Find files by name pattern.
Sourcepub fn all_files(&self) -> Vec<String>
pub fn all_files(&self) -> Vec<String>
Get all indexed files without pattern matching. This is more efficient than using find_files(“.*”).
Sourcepub fn get_file_content(
&self,
file_path: &str,
start_line: Option<usize>,
end_line: Option<usize>,
) -> Result<String, Error>
pub fn get_file_content( &self, file_path: &str, start_line: Option<usize>, end_line: Option<usize>, ) -> Result<String, Error>
Get file content with line numbers.