Module patch

Module patch 

Structs

Patch
Represents a complete patch comprised of multiple operations.
PatchChunk
Represents a chunk of changes within an update operation.

Enums

PatchError
Errors produced while parsing or applying agent patches.
PatchLine
Represents a single diff line inside a patch hunk.
PatchOperation
Represents a patch operation.

Functions

render_patch_update_content

Type Aliases

PatchHunk