Apply Patch Interception (from Codex)
This module provides the ability to intercept shell commands that contain apply_patch invocations, redirecting them to the proper patch application flow with approval and sandbox handling.
Structs
- Apply
Patch Request - Apply patch request (from Codex)
Enums
- Apply
Patch Error - Errors from apply_patch interception
Constants
- CODEX_
APPLY_ PATCH_ ARG - The argument used to indicate apply_patch mode (from Codex)
Functions
- intercept_
apply_ patch - Intercept apply_patch from shell command (from Codex)
- maybe_
parse_ apply_ patch_ from_ command - Check if a command contains an apply_patch invocation (from Codex)