Planning workflow scoped task tracker persisted next to the active plan file.
This tracker is intended for Planning workflow only and writes a sidecar markdown
file next to the active plan file (<plan>.tasks.md).
Planning workflow scoped task tracker persisted next to the active plan file.
This tracker is intended for Planning workflow only and writes a sidecar markdown
file next to the active plan file (<plan>.tasks.md).