Module names

Module names 

Functions

canonical_tool_name
Use direct tool name without alias resolution. Alias resolution is now handled by the tool registry inventory which maintains a mapping of aliases to canonical tool names.