pub const fn canonical_tool_name(name: &str) -> &str
Use direct tool name without alias resolution. Alias resolution is now handled by the tool registry inventory which maintains a mapping of aliases to canonical tool names.