Module slash

Module slash 

Structs

SlashCommandInfo
Metadata describing a slash command supported by the chat interface.

Statics

SLASH_COMMANDS
Collection of slash command definitions in the order they should be displayed.

Functions

find_command
find_visible_command
suggestions_for
Returns slash command metadata that match the provided prefix (case insensitive).
suggestions_for_terminal
visible_commands
visible_commands_for_terminal