Theme Configuration File Support
Parses custom .vtcode/theme.toml files with Git/LS-style syntax for colors. This allows users to customize colors beyond system defaults.
Structs
- CliColors
- Colors for CLI elements like prompts, messages, etc.
- Diff
Colors - Colors for diff rendering
- File
Colors - File type colors using LS_COLORS-style patterns
- Parsed
CliColors - Parsed CLI colors with anstyle::Style values
- Parsed
Diff Colors - Parsed diff colors with anstyle::Style values
- Parsed
File Colors - Parsed file colors with anstyle::Style values
- Parsed
Status Colors - Parsed status colors with anstyle::Style values
- Status
Colors - Colors for status output
- Theme
Config - Theme configuration that can be loaded from a .vtcode/theme.toml file