Theme manager for loading and applying custom themes. Theme Manager for loading and applying custom theme configurations
This module provides functionality to load custom theme configurations from .vtcode/theme.toml files and apply them to the application.
Structs
- Theme
Manager - Loads and manages theme configuration from
.vtcode/theme.tomland Git config.