Module dot_config

Module dot_config 

Dot folder configuration and cache management

Structs

CacheCleanupStats
CacheConfig
DependencyNoticeStore
DiskUsageStats
DotConfig
VT Code configuration stored in ~/.vtcode/
DotManager
Dot folder manager for VT Code configuration and cache
ProviderConfig
ProviderConfigs
UiConfig
UserPreferences
WorkspaceTrustRecord
WorkspaceTrustStore

Enums

DotError
Dot folder management errors
WorkspaceTrustLevel
Workspace trust levels exposed through the Agent Client Protocol configuration.

Functions

get_dot_manager
Get global dot manager instance
initialize_dot_folder
Initialize dot folder (should be called at startup)
load_user_config
Load user configuration
load_workspace_trust_level
Load the trust level recorded for a workspace, if any.
save_user_config
Save user configuration
update_model_preference
Persist the preferred provider and model combination.
update_theme_preference
Persist the preferred UI theme in the user’s dot configuration.
update_workspace_trust
Persist the trust level recorded for a workspace.