Dot folder configuration and cache management
Structs
- Cache
Cleanup Stats - Cache
Config - Dependency
Notice Store - Disk
Usage Stats - DotConfig
- VT Code configuration stored in ~/.vtcode/
- DotManager
- Dot folder manager for VT Code configuration and cache
- Provider
Config - Provider
Configs - UiConfig
- User
Preferences - Workspace
Trust Record - Workspace
Trust Store
Enums
- DotError
- Dot folder management errors
- Workspace
Trust Level - Workspace trust levels exposed through the Agent Client Protocol configuration.
Functions
- get_
dot_ manager - Get global dot manager instance
- initialize_
dot_ folder - Initialize dot folder (should be called at startup)
- load_
user_ config - Load user configuration
- load_
workspace_ trust_ level - Load the trust level recorded for a workspace, if any.
- save_
user_ config - Save user configuration
- update_
model_ preference - Persist the preferred provider and model combination.
- update_
theme_ preference - Persist the preferred UI theme in the user’s dot configuration.
- update_
workspace_ trust - Persist the trust level recorded for a workspace.