pub struct SessionArchive { /* private fields */ }Implementations
Sourceimpl SessionArchive
impl SessionArchive
pub async fn new( metadata: SessionArchiveMetadata, custom_suffix: Option<String>, ) -> Result<Self>
Sourcepub async fn new_with_identifier(
metadata: SessionArchiveMetadata,
session_identifier: String,
) -> Result<Self>
pub async fn new_with_identifier( metadata: SessionArchiveMetadata, session_identifier: String, ) -> Result<Self>
Create a session archive using an explicitly reserved session identifier.
Sourcepub fn resume_from_listing(
listing: &SessionListing,
metadata: SessionArchiveMetadata,
) -> Self
pub fn resume_from_listing( listing: &SessionListing, metadata: SessionArchiveMetadata, ) -> Self
Reopen an existing archive file so follow-up runs can overwrite the snapshot in place.
pub fn finalize( &self, transcript: Vec<String>, total_messages: usize, distinct_tools: Vec<String>, messages: Vec<SessionMessage>, ) -> Result<PathBuf>
pub fn persist_progress(&self, args: SessionProgressArgs) -> Result<PathBuf>
pub async fn persist_progress_async( &self, args: SessionProgressArgs, ) -> Result<PathBuf>
Sourcepub fn set_loaded_skills(&mut self, skills: Vec<String>)
pub fn set_loaded_skills(&mut self, skills: Vec<String>)
Update loaded skills in the archive metadata
Sourcepub fn set_continuation_metadata(
&mut self,
continuation_metadata: Option<SessionContinuationMetadata>,
)
pub fn set_continuation_metadata( &mut self, continuation_metadata: Option<SessionContinuationMetadata>, )
Update continuation metadata in the archive metadata.
pub fn path(&self) -> &Path
Sourcepub async fn fork(
source_snapshot: &SessionSnapshot,
custom_suffix: Option<String>,
) -> Result<Self>
pub async fn fork( source_snapshot: &SessionSnapshot, custom_suffix: Option<String>, ) -> Result<Self>
Create a forked session from an existing session snapshot
This creates a new session archive that inherits metadata from the source session but operates independently. The forked session will have a new archive file with a custom suffix if provided.
Arguments
source_snapshot- The snapshot of the session to fork fromcustom_suffix- Optional custom suffix for the new session ID
Returns
A new SessionArchive instance for the forked session