Module style_helpers

Module style_helpers 

Re-exports from vtcode-commons for backward compatibility.

Structs

ColorPalette
Standard color palette with semantic names
DiffColorPalette
Diff color palette for consistent git diff styling Uses standard ANSI colors without bold for accessibility and consistency.

Enums

DiffColorLevel
Terminal color capability level for palette selection.
DiffTheme
Terminal background theme for diff rendering.

Functions

bold_color
Create a bold colored style from AnsiColor
diff_add_bg
Get background color for addition lines based on theme and color level.
diff_del_bg
Get background color for deletion lines based on theme and color level.
diff_gutter_bg_add_light
Get gutter background color for addition lines in light theme.
diff_gutter_bg_del_light
Get gutter background color for deletion lines in light theme.
diff_gutter_fg_light
Get gutter foreground color for light theme (dark theme uses dimmed default).
dimmed_color
Create a dimmed colored style from AnsiColor
render_styled
Render text with a single color and optional effects
style_from_color_name
Build style from CSS/terminal color name