Module transcript

Module transcript 

Re-exports

pub use crate::utils::message_style::MessageStyle;

Functions

append
clear
clear_inline_handle
Remove the inline handle
clear_queue
Clear the message queue
display_error
Display an error message in the transcript instead of the input field
display_immediate
Display a message immediately without enqueueing or adding to transcript
display_info
Display an info message in the transcript instead of the input field
enqueue
Enqueue a message and display it immediately (defaults to Output/Pty style)
enqueue_message
Enqueue a message with a specific style and display it immediately
enqueue_message_with_kind
Enqueue a message with a specific kind and display it immediately
get_queued_messages
Get all queued messages as plain text
get_queued_messages_with_metadata
Get all queued messages with their metadata
len
queue_len
Get queue length
replace_last
replay_queued_messages
Replay all queued messages to the current inline handle (useful for recovery)
set_inline_handle
Set the inline handle for immediate message display
snapshot
tail_matches
with_suppressed