Re-exports
pub use crate::utils::message_style::MessageStyle;
Functions
- append
- clear
- clear_
inline_ handle - Remove the inline handle
- clear_
queue - Clear the message queue
- display_
error - Display an error message in the transcript instead of the input field
- display_
immediate - Display a message immediately without enqueueing or adding to transcript
- display_
info - Display an info message in the transcript instead of the input field
- enqueue
- Enqueue a message and display it immediately (defaults to Output/Pty style)
- enqueue_
message - Enqueue a message with a specific style and display it immediately
- enqueue_
message_ with_ kind - Enqueue a message with a specific kind and display it immediately
- get_
queued_ messages - Get all queued messages as plain text
- get_
queued_ messages_ with_ metadata - Get all queued messages with their metadata
- len
- queue_
len - Get queue length
- replace_
last - replay_
queued_ messages - Replay all queued messages to the current inline handle (useful for recovery)
- set_
inline_ handle - Set the inline handle for immediate message display
- snapshot
- tail_
matches - with_
suppressed